==> iaxmodem_1.1.0~dfsg.orig.tar.gz: iaxmodem-1.1.0/lib/spandsp/src/v22bis_rx_1200_fixed_rrc.h <==
#define PULSESHAPER_1200_GAIN        32767.000000f
#define PULSESHAPER_1200_COEFF_SETS  12
static const complexi16_t pulseshaper_1200[PULSESHAPER_1200_COEFF_SETS][37] =
{
    {
        {       0,        0},     /* Filter 0 */
        {     125,      -40},
        {     162,      118},
        {       0,      257},
        {    -234,      170},
        {    -269,      -87},
        {     -70,     -216},
        {      66,      -90},
        {     -65,        0},
        {    -180,     -248},
        {     187,     -576},
        {     903,     -293},
        {    1071,      778},
        {       0,     1705},
        {   -1676,     1218},
        {   -2284,     -742},
        {    -825,    -2540},
        {    1681,    -2314},
        {    2960,        0},
        {    1739,     2394},
        {    -884,     2721},
        {   -2540,      825},
        {   -1943,    -1411},
        {       0,    -2072},
        {    1379,    -1002},
        {    1259,      409},
        {     293,      903},
        {    -356,      490},
        {    -307,        0},
        {     -38,      -53},
        {     -34,      106},
        {    -216,       70},
        {    -229,     -166},
        {       0,     -289},
        {     208,     -151},
        {     191,       62},
        {      40,      125}
    },
    {
        {       0,        0},     /* Filter 1 */
        {     131,      -42},
        {     166,      121},
        {       0,      261},
        {    -235,      170},
        {    -266,      -86},
        {     -67,     -209},
        {      58,      -80},
        {     -83,        0},
        {    -194,     -267},
        {     195,     -602},
        {     932,     -303},
        {    1096,      796},
        {       0,     1737},
        {   -1700,     1235},
        {   -2308,     -749},
        {    -831,    -2558},
        {    1688,    -2324},
        {    2964,        0},
        {    1737,     2391},
        {    -880,     2709},
        {   -2521,      819},
        {   -1922,    -1396},
        {       0,    -2043},
        {    1354,     -983},
        {    1228,      399},
        {     284,      875},
        {    -340,      468},
        {    -284,        0},
        {     -28,      -39},
        {     -38,      118},
        {    -222,       72},
        {    -231,     -167},
        {       0,     -288},
        {     205,     -149},
        {     185,       60},
        {      39,      120}
    },
    {
        {       0,        0},     /* Filter 2 */
        {     136,      -44},
        {     171,      124},
        {       0,      265},
        {    -235,      171},
        {    -264,      -85},
        {     -65,     -201},
        {      51,      -70},
        {    -101,        0},
        {    -207,     -285},
        {     204,     -628},
        {     961,     -312},
        {    1122,      815},
        {       0,     1768},
        {   -1723,     1252},
        {   -2331,     -757},
        {    -836,    -2575},
        {    1695,    -2333},
        {    2967,        0},
        {    1734,     2387},
        {    -876,     2696},
        {   -2502,      813},
        {   -1901,    -1381},
        {       0,    -2013},
        {    1328,     -965},
        {    1198,      389},
        {     275,      847},
        {    -324,      447},
        {    -262,        0},
        {     -18,      -25},
        {     -41,      129},
        {    -228,       74},
        {    -232,     -168},
        {       0,     -286},
        {     201,     -146},
        {     180,       58},
        {      37,      114}
    },
    {
        {       0,        0},     /* Filter 3 */
        {     142,      -46},
        {     175,      127},
        {       0,      268},
        {    -236,      171},
        {    -260,      -84},
        {     -63,     -194},
        {      43,      -59},
        {    -120,        0},
        {    -221,     -305},
        {     212,     -654},
        {     990,     -321},
        {    1148,      834},
        {       0,     1799},
        {   -1747,     1269},
        {   -2354,     -764},
        {    -842,    -2593},
        {    1701,    -2342},
        {    2969,        0},
        {    1730,     2382},
        {    -872,     2683},
        {   -2482,      806},
        {   -1880,    -1366},
        {       0,    -1983},
        {    1303,     -946},
        {    1168,      379},
        {     266,      818},
        {    -309,      426},
        {    -241,        0},
        {      -8,      -12},
        {     -45,      139},
        {    -234,       76},
        {    -233,     -169},
        {       0,     -284},
        {     198,     -144},
        {     175,       56},
        {      35,      108}
    },
    {
        {       0,        0},     /* Filter 4 */
        {     148,      -48},
        {     179,      130},
        {       0,      271},
        {    -236,      171},
        {    -257,      -83},
        {     -60,     -186},
        {      35,      -48},
        {    -139,        0},
        {    -235,     -324},
        {     221,     -681},
        {    1020,     -331},
        {    1174,      853},
        {       0,     1830},
        {   -1769,     1285},
        {   -2376,     -772},
        {    -847,    -2609},
        {    1707,    -2350},
        {    2971,        0},
        {    1726,     2376},
        {    -867,     2670},
        {   -2462,      800},
        {   -1858,    -1350},
        {       0,    -1953},
        {    1277,     -928},
        {    1138,      370},
        {     256,      790},
        {    -294,      405},
        {    -220,        0},
        {       0,        0},
        {     -48,      149},
        {    -239,       77},
        {    -234,     -170},
        {       0,     -282},
        {     194,     -141},
        {     169,       55},
        {      33,      103}
    },
    {
        {       0,        0},     /* Filter 5 */
        {     153,      -49},
        {     183,      133},
        {       0,      274},
        {    -236,      171},
        {    -253,      -82},
        {     -57,     -177},
        {      26,      -37},
        {    -159,        0},
        {    -250,     -344},
        {     230,     -708},
        {    1049,     -341},
        {    1199,      871},
        {       0,     1861},
        {   -1792,     1302},
        {   -2398,     -779},
        {    -853,    -2625},
        {    1712,    -2357},
        {    2972,        0},
        {    1722,     2371},
        {    -862,     2655},
        {   -2441,      793},
        {   -1837,    -1334},
        {       0,    -1923},
        {    1251,     -909},
        {    1108,      360},
        {     247,      763},
        {    -279,      384},
        {    -199,        0},
        {       9,       13},
        {     -51,      159},
        {    -244,       79},
        {    -235,     -171},
        {       0,     -280},
        {     191,     -138},
        {     164,       53},
        {      31,       97}
    },
    {
        {       0,        0},     /* Filter 6 */
        {     159,      -51},
        {     187,      136},
        {       0,      277},
        {    -236,      171},
        {    -249,      -80},
        {     -54,     -168},
        {      18,      -25},
        {    -178,        0},
        {    -264,     -364},
        {     239,     -735},
        {    1079,     -350},
        {    1225,      890},
        {       0,     1892},
        {   -1814,     1318},
        {   -2420,     -786},
        {    -858,    -2641},
        {    1718,    -2364},
        {    2972,        0},
        {    1718,     2364},
        {    -858,     2641},
        {   -2420,      786},
        {   -1814,    -1318},
        {       0,    -1892},
        {    1225,     -890},
        {    1079,      350},
        {     239,      735},
        {    -264,      364},
        {    -178,        0},
        {      18,       25},
        {     -54,      168},
        {    -249,       80},
        {    -236,     -171},
        {       0,     -277},
        {     187,     -136},
        {     159,       51},
        {      29,       92}
    },
    {
        {       0,        0},     /* Filter 7 */
        {     164,      -53},
        {     191,      138},
        {       0,      280},
        {    -235,      171},
        {    -244,      -79},
        {     -51,     -159},
        {       9,      -13},
        {    -199,        0},
        {    -279,     -384},
        {     247,     -763},
        {    1108,     -360},
        {    1251,      909},
        {       0,     1923},
        {   -1837,     1334},
        {   -2441,     -793},
        {    -862,    -2655},
        {    1722,    -2371},
        {    2972,        0},
        {    1712,     2357},
        {    -853,     2625},
        {   -2398,      779},
        {   -1792,    -1302},
        {       0,    -1861},
        {    1199,     -871},
        {    1049,      341},
        {     230,      708},
        {    -250,      344},
        {    -159,        0},
        {      26,       37},
        {     -57,      177},
        {    -253,       82},
        {    -236,     -171},
        {       0,     -274},
        {     183,     -133},
        {     153,       49},
        {      28,       86}
    },
    {
        {       0,        0},     /* Filter 8 */
        {     169,      -55},
        {     194,      141},
        {       0,      282},
        {    -234,      170},
        {    -239,      -77},
        {     -48,     -149},
        {       0,        0},
        {    -220,        0},
        {    -294,     -405},
        {     256,     -790},
        {    1138,     -370},
        {    1277,      928},
        {       0,     1953},
        {   -1858,     1350},
        {   -2462,     -800},
        {    -867,    -2670},
        {    1726,    -2376},
        {    2971,        0},
        {    1707,     2350},
        {    -847,     2609},
        {   -2376,      772},
        {   -1769,    -1285},
        {       0,    -1830},
        {    1174,     -853},
        {    1020,      331},
        {     221,      681},
        {    -235,      324},
        {    -139,        0},
        {      35,       48},
        {     -60,      186},
        {    -257,       83},
        {    -236,     -171},
        {       0,     -271},
        {     179,     -130},
        {     148,       48},
        {      26,       81}
    },
    {
        {       0,        0},     /* Filter 9 */
        {     175,      -56},
        {     198,      144},
        {       0,      284},
        {    -233,      169},
        {    -234,      -76},
        {     -45,     -139},
        {      -8,       12},
        {    -241,        0},
        {    -309,     -426},
        {     266,     -818},
        {    1168,     -379},
        {    1303,      946},
        {       0,     1983},
        {   -1880,     1366},
        {   -2482,     -806},
        {    -872,    -2683},
        {    1730,    -2382},
        {    2969,        0},
        {    1701,     2342},
        {    -842,     2593},
        {   -2354,      764},
        {   -1747,    -1269},
        {       0,    -1799},
        {    1148,     -834},
        {     990,      321},
        {     212,      654},
        {    -221,      305},
        {    -120,        0},
        {      43,       59},
        {     -63,      194},
        {    -260,       84},
        {    -236,     -171},
        {       0,     -268},
        {     175,     -127},
        {     142,       46},
        {      24,       75}
    },
    {
        {       0,        0},     /* Filter 10 */
        {     180,      -58},
        {     201,      146},
        {       0,      286},
        {    -232,      168},
        {    -228,      -74},
        {     -41,     -129},
        {     -18,       25},
        {    -262,        0},
        {    -324,     -447},
        {     275,     -847},
        {    1198,     -389},
        {    1328,      965},
        {       0,     2013},
        {   -1901,     1381},
        {   -2502,     -813},
        {    -876,    -2696},
        {    1734,    -2387},
        {    2967,        0},
        {    1695,     2333},
        {    -836,     2575},
        {   -2331,      757},
        {   -1723,    -1252},
        {       0,    -1768},
        {    1122,     -815},
        {     961,      312},
        {     204,      628},
        {    -207,      285},
        {    -101,        0},
        {      51,       70},
        {     -65,      201},
        {    -264,       85},
        {    -235,     -171},
        {       0,     -265},
        {     171,     -124},
        {     136,       44},
        {      22,       70}
    },
    {
        {       0,        0},     /* Filter 11 */
        {     185,      -60},
        {     205,      149},
        {       0,      288},
        {    -231,      167},
        {    -222,      -72},
        {     -38,     -118},
        {     -28,       39},
        {    -284,        0},
        {    -340,     -468},
        {     284,     -875},
        {    1228,     -399},
        {    1354,      983},
        {       0,     2043},
        {   -1922,     1396},
        {   -2521,     -819},
        {    -880,    -2709},
        {    1737,    -2391},
        {    2964,        0},
        {    1688,     2324},
        {    -831,     2558},
        {   -2308,      749},
        {   -1700,    -1235},
        {       0,    -1737},
        {    1096,     -796},
        {     932,      303},
        {     195,      602},
        {    -194,      267},
        {     -83,        0},
        {      58,       80},
        {     -67,      209},
        {    -266,       86},
        {    -235,     -170},
        {       0,     -261},
        {     166,     -121},
        {     131,       42},
        {      21,       65}
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v22bis_rx_1200_fixed_rrc.h <==
#define RX_PULSESHAPER_1200_GAIN        32767.000000f
#define RX_PULSESHAPER_1200_COEFF_SETS  12
static const complexi16_t rx_pulseshaper_1200[RX_PULSESHAPER_1200_COEFF_SETS][37] =
{
    {
        {       0,        0},     /* Filter 0 */
        {     125,      -40},
        {     162,      118},
        {       0,      257},
        {    -234,      170},
        {    -269,      -87},
        {     -70,     -216},
        {      66,      -90},
        {     -65,        0},
        {    -180,     -248},
        {     187,     -576},
        {     903,     -293},
        {    1071,      778},
        {       0,     1705},
        {   -1676,     1218},
        {   -2284,     -742},
        {    -825,    -2540},
        {    1681,    -2314},
        {    2960,        0},
        {    1739,     2394},
        {    -884,     2721},
        {   -2540,      825},
        {   -1943,    -1411},
        {       0,    -2072},
        {    1379,    -1002},
        {    1259,      409},
        {     293,      903},
        {    -356,      490},
        {    -307,        0},
        {     -38,      -53},
        {     -34,      106},
        {    -216,       70},
        {    -229,     -166},
        {       0,     -289},
        {     208,     -151},
        {     191,       62},
        {      40,      125}
    },
    {
        {       0,        0},     /* Filter 1 */
        {     131,      -42},
        {     166,      121},
        {       0,      261},
        {    -235,      170},
        {    -266,      -86},
        {     -67,     -209},
        {      58,      -80},
        {     -83,        0},
        {    -194,     -267},
        {     195,     -602},
        {     932,     -303},
        {    1096,      796},
        {       0,     1737},
        {   -1700,     1235},
        {   -2308,     -749},
        {    -831,    -2558},
        {    1688,    -2324},
        {    2964,        0},
        {    1737,     2391},
        {    -880,     2709},
        {   -2521,      819},
        {   -1922,    -1396},
        {       0,    -2043},
        {    1354,     -983},
        {    1228,      399},
        {     284,      875},
        {    -340,      468},
        {    -284,        0},
        {     -28,      -39},
        {     -38,      118},
        {    -222,       72},
        {    -231,     -167},
        {       0,     -288},
        {     205,     -149},
        {     185,       60},
        {      39,      120}
    },
    {
        {       0,        0},     /* Filter 2 */
        {     136,      -44},
        {     171,      124},
        {       0,      265},
        {    -235,      171},
        {    -264,      -85},
        {     -65,     -201},
        {      51,      -70},
        {    -101,        0},
        {    -207,     -285},
        {     204,     -628},
        {     961,     -312},
        {    1122,      815},
        {       0,     1768},
        {   -1723,     1252},
        {   -2331,     -757},
        {    -836,    -2575},
        {    1695,    -2333},
        {    2967,        0},
        {    1734,     2387},
        {    -876,     2696},
        {   -2502,      813},
        {   -1901,    -1381},
        {       0,    -2013},
        {    1328,     -965},
        {    1198,      389},
        {     275,      847},
        {    -324,      447},
        {    -262,        0},
        {     -18,      -25},
        {     -41,      129},
        {    -228,       74},
        {    -232,     -168},
        {       0,     -286},
        {     201,     -146},
        {     180,       58},
        {      37,      114}
    },
    {
        {       0,        0},     /* Filter 3 */
        {     142,      -46},
        {     175,      127},
        {       0,      268},
        {    -236,      171},
        {    -260,      -84},
        {     -63,     -194},
        {      43,      -59},
        {    -120,        0},
        {    -221,     -305},
        {     212,     -654},
        {     990,     -321},
        {    1148,      834},
        {       0,     1799},
        {   -1747,     1269},
        {   -2354,     -764},
        {    -842,    -2593},
        {    1701,    -2342},
        {    2969,        0},
        {    1730,     2382},
        {    -872,     2683},
        {   -2482,      806},
        {   -1880,    -1366},
        {       0,    -1983},
        {    1303,     -946},
        {    1168,      379},
        {     266,      818},
        {    -309,      426},
        {    -241,        0},
        {      -8,      -12},
        {     -45,      139},
        {    -234,       76},
        {    -233,     -169},
        {       0,     -284},
        {     198,     -144},
        {     175,       56},
        {      35,      108}
    },
    {
        {       0,        0},     /* Filter 4 */
        {     148,      -48},
        {     179,      130},
        {       0,      271},
        {    -236,      171},
        {    -257,      -83},
        {     -60,     -186},
        {      35,      -48},
        {    -139,        0},
        {    -235,     -324},
        {     221,     -681},
        {    1020,     -331},
        {    1174,      853},
        {       0,     1830},
        {   -1769,     1285},
        {   -2376,     -772},
        {    -847,    -2609},
        {    1707,    -2350},
        {    2971,        0},
        {    1726,     2376},
        {    -867,     2670},
        {   -2462,      800},
        {   -1858,    -1350},
        {       0,    -1953},
        {    1277,     -928},
        {    1138,      370},
        {     256,      790},
        {    -294,      405},
        {    -220,        0},
        {       0,        0},
        {     -48,      149},
        {    -239,       77},
        {    -234,     -170},
        {       0,     -282},
        {     194,     -141},
        {     169,       55},
        {      33,      103}
    },
    {
        {       0,        0},     /* Filter 5 */
        {     153,      -49},
        {     183,      133},
        {       0,      274},
        {    -236,      171},
        {    -253,      -82},
        {     -57,     -177},
        {      26,      -37},
        {    -159,        0},
        {    -250,     -344},
        {     230,     -708},
        {    1049,     -341},
        {    1199,      871},
        {       0,     1861},
        {   -1792,     1302},
        {   -2398,     -779},
        {    -853,    -2625},
        {    1712,    -2357},
        {    2972,        0},
        {    1722,     2371},
        {    -862,     2655},
        {   -2441,      793},
        {   -1837,    -1334},
        {       0,    -1923},
        {    1251,     -909},
        {    1108,      360},
        {     247,      763},
        {    -279,      384},
        {    -199,        0},
        {       9,       13},
        {     -51,      159},
        {    -244,       79},
        {    -235,     -171},
        {       0,     -280},
        {     191,     -138},
        {     164,       53},
        {      31,       97}
    },
    {
        {       0,        0},     /* Filter 6 */
        {     159,      -51},
        {     187,      136},
        {       0,      277},
        {    -236,      171},
        {    -249,      -80},
        {     -54,     -168},
        {      18,      -25},
        {    -178,        0},
        {    -264,     -364},
        {     239,     -735},
        {    1079,     -350},
        {    1225,      890},
        {       0,     1892},
        {   -1814,     1318},
        {   -2420,     -786},
        {    -858,    -2641},
        {    1718,    -2364},
        {    2972,        0},
        {    1718,     2364},
        {    -858,     2641},
        {   -2420,      786},
        {   -1814,    -1318},
        {       0,    -1892},
        {    1225,     -890},
        {    1079,      350},
        {     239,      735},
        {    -264,      364},
        {    -178,        0},
        {      18,       25},
        {     -54,      168},
        {    -249,       80},
        {    -236,     -171},
        {       0,     -277},
        {     187,     -136},
        {     159,       51},
        {      29,       92}
    },
    {
        {       0,        0},     /* Filter 7 */
        {     164,      -53},
        {     191,      138},
        {       0,      280},
        {    -235,      171},
        {    -244,      -79},
        {     -51,     -159},
        {       9,      -13},
        {    -199,        0},
        {    -279,     -384},
        {     247,     -763},
        {    1108,     -360},
        {    1251,      909},
        {       0,     1923},
        {   -1837,     1334},
        {   -2441,     -793},
        {    -862,    -2655},
        {    1722,    -2371},
        {    2972,        0},
        {    1712,     2357},
        {    -853,     2625},
        {   -2398,      779},
        {   -1792,    -1302},
        {       0,    -1861},
        {    1199,     -871},
        {    1049,      341},
        {     230,      708},
        {    -250,      344},
        {    -159,        0},
        {      26,       37},
        {     -57,      177},
        {    -253,       82},
        {    -236,     -171},
        {       0,     -274},
        {     183,     -133},
        {     153,       49},
        {      28,       86}
    },
    {
        {       0,        0},     /* Filter 8 */
        {     169,      -55},
        {     194,      141},
        {       0,      282},
        {    -234,      170},
        {    -239,      -77},
        {     -48,     -149},
        {       0,        0},
        {    -220,        0},
        {    -294,     -405},
        {     256,     -790},
        {    1138,     -370},
        {    1277,      928},
        {       0,     1953},
        {   -1858,     1350},
        {   -2462,     -800},
        {    -867,    -2670},
        {    1726,    -2376},
        {    2971,        0},
        {    1707,     2350},
        {    -847,     2609},
        {   -2376,      772},
        {   -1769,    -1285},
        {       0,    -1830},
        {    1174,     -853},
        {    1020,      331},
        {     221,      681},
        {    -235,      324},
        {    -139,        0},
        {      35,       48},
        {     -60,      186},
        {    -257,       83},
        {    -236,     -171},
        {       0,     -271},
        {     179,     -130},
        {     148,       48},
        {      26,       81}
    },
    {
        {       0,        0},     /* Filter 9 */
        {     175,      -56},
        {     198,      144},
        {       0,      284},
        {    -233,      169},
        {    -234,      -76},
        {     -45,     -139},
        {      -8,       12},
        {    -241,        0},
        {    -309,     -426},
        {     266,     -818},
        {    1168,     -379},
        {    1303,      946},
        {       0,     1983},
        {   -1880,     1366},
        {   -2482,     -806},
        {    -872,    -2683},
        {    1730,    -2382},
        {    2969,        0},
        {    1701,     2342},
        {    -842,     2593},
        {   -2354,      764},
        {   -1747,    -1269},
        {       0,    -1799},
        {    1148,     -834},
        {     990,      321},
        {     212,      654},
        {    -221,      305},
        {    -120,        0},
        {      43,       59},
        {     -63,      194},
        {    -260,       84},
        {    -236,     -171},
        {       0,     -268},
        {     175,     -127},
        {     142,       46},
        {      24,       75}
    },
    {
        {       0,        0},     /* Filter 10 */
        {     180,      -58},
        {     201,      146},
        {       0,      286},
        {    -232,      168},
        {    -228,      -74},
        {     -41,     -129},
        {     -18,       25},
        {    -262,        0},
        {    -324,     -447},
        {     275,     -847},
        {    1198,     -389},
        {    1328,      965},
        {       0,     2013},
        {   -1901,     1381},
        {   -2502,     -813},
        {    -876,    -2696},
        {    1734,    -2387},
        {    2967,        0},
        {    1695,     2333},
        {    -836,     2575},
        {   -2331,      757},
        {   -1723,    -1252},
        {       0,    -1768},
        {    1122,     -815},
        {     961,      312},
        {     204,      628},
        {    -207,      285},
        {    -101,        0},
        {      51,       70},
        {     -65,      201},
        {    -264,       85},
        {    -235,     -171},
        {       0,     -265},
        {     171,     -124},
        {     136,       44},
        {      22,       70}
    },
    {
        {       0,        0},     /* Filter 11 */
        {     185,      -60},
        {     205,      149},
        {       0,      288},
        {    -231,      167},
        {    -222,      -72},
        {     -38,     -118},
        {     -28,       39},
        {    -284,        0},
        {    -340,     -468},
        {     284,     -875},
        {    1228,     -399},
        {    1354,      983},
        {       0,     2043},
        {   -1922,     1396},
        {   -2521,     -819},
        {    -880,    -2709},
        {    1737,    -2391},
        {    2964,        0},
        {    1688,     2324},
        {    -831,     2558},
        {   -2308,      749},
        {   -1700,    -1235},
        {       0,    -1737},
        {    1096,     -796},
        {     932,      303},
        {     195,      602},
        {    -194,      267},
        {     -83,        0},
        {      58,       80},
        {     -67,      209},
        {    -266,       86},
        {    -235,     -170},
        {       0,     -261},
        {     166,     -121},
        {     131,       42},
        {      21,       65}
    }
};
